#!/usr/bin/env python3
# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

import logging
import os

import torch


def _load_library(filename: str) -> None:
    """Load a shared library from the given filename."""
    try:
        torch.ops.load_library(os.path.join(os.path.dirname(__file__), filename))
    except Exception as error:
        logging.warning(
            f"Could not the library '{filename}': {error}.  This may be expected depending on the FBGEMM_GPU variant."
        )


for filename in [
    "fbgemm_gpu_py.so",
    "experimental/gen_ai/fbgemm_gpu_experimental_gen_ai_py.so",
]:
    _load_library(filename)

# Since __init__.py is only used in OSS context, we define `open_source` here
# and use its existence to determine whether or not we are in OSS context
open_source: bool = True

# Trigger the manual addition of docstrings to pybind11-generated operators
import fbgemm_gpu.docs  # noqa: F401, E402

try:
    # Export the version string from the version file auto-generated by setup.py
    from fbgemm_gpu.docs.version import __variant__, __version__  # noqa: F401, E402
except Exception:
    __variant__: str = "NONE"
    __version__: str = "NONE"

try:
    # Trigger meta operator registrations
    from . import sparse_ops  # noqa: F401, E402
except Exception:
    pass
